@@ -21,9 +21,9 @@ def before_test(request):
     chrome_options = ChromeOptions()
     # In metamask wallet type
     if pytest.data_driven.get("wallet_type") == 'MetaMask':
-        chrome_options.add_extension(pytest.project_dir + pytest.properties.get("metamask.extension.crx"))
+        chrome_options.add_extension(pytest.user_dir + pytest.properties.get("metamask.extension.crx"))
     elif pytest.data_driven.get("wallet_type") == 'Coinbase':
-        chrome_options.add_extension(pytest.project_dir + pytest.properties.get("coinbase.extension.crx"))
+        chrome_options.add_extension(pytest.user_dir + pytest.properties.get("coinbase.extension.crx"))
 
     # If brave browser driver type injected - add brave binary_location to chrome_options
     if pytest.data_driven.get("browser") == "brave":
